@@ -6,75 +6,82 @@ Async::Simple::Pool - Simple manager of asyncronous tasks
 
 =head1 SYNOPSIS
 
-    Simplest way:
+Simplest way:
 
-        use Async::Simple::Pool;
-        use Data::Dumper;
+    use Async::Simple::Pool;
+    use Data::Dumper;
 
-        my $task = sub{
-            my $data = shift;
+    my $task = sub{
+        my $data = shift;
 
-            return $data->{i} * 10;
-        };
+        return $data->{i} * 10;
+    };
 
-        my $data = [ { i => 1 }, { i => 2 }, { i => 3 } ];
+    my $data = [ { i => 1 }, { i => 2 }, { i => 3 } ];
 
-        my $pool = Async::Simple::Pool->new( $task, $data );
+    my $pool = Async::Simple::Pool->new( $task, $data );
 
-        my $result = $pool->process;
+    my $result = $pool->process;
 
-        say Dumper $result;
+    say Dumper $result;
 
-        $VAR1 = [
-                  10,
-                  20,
-                  30
-                ];
+    $VAR1 = [
+              10,
+              20,
+              30
+            ];
 
 
-    Next step ( $pool->new() with various param sets ):
+Some other ways to do $pool->new(), using various param sets.
 
-        Init of pool must be done in different ways:
+Note: If you pass $data to $pool->new() then all processes will be started immediately.
+You can call $pool->process after "new" and get your results in no time.
 
-        If you pass $data to $pool->new() then all processes will be started immediately.
-        You can call $pool->process after "new" and get your results in no time.
+    my $pool = Async::Simple::Pool->new( $task, $data );               # Simplest way to create a new pool. Results will be available just after "new"
+
+    my $pool = Async::Simple::Pool->new( %pool_params );               # Creates a new pool. The only one param "task" is required by default.
+
+    my $pool = Async::Simple::Pool->new( $task, %pool_params );        # "$task" is required, al params are optional
+
+    my $pool = Async::Simple::Pool->new( $data, %pool_params );        # $data - required, all pool_params except "task" are optional
+
+    my $pool = Async::Simple::Pool->new( $task, $data, %pool_params ); # $task, $data - required, all pool_params are optional
 
 
-        # Few ways to create pool object:
+By default "task" is required and must be a CodeRef.
+For example:
 
-            my $pool = Async::Simple::Pool->new( $task, $data );
-
-            my $pool = Async::Simple::Pool->new( %pool_params );               # Creates a new pool. The only one param "task" is required by default.
-
-            my $pool = Async::Simple::Pool->new( $task, %pool_params );        # "$task" is required, al params are optional
-
-            my $pool = Async::Simple::Pool->new( $data, %pool_params );        # $data - required, all pool_params except "task" are optional
-
-            my $pool = Async::Simple::Pool->new( $task, $data, %pool_params ); # $task, $data - required, all pool_params are optional
+    $task = sub { my $task_X_data = shift; some useful code; return $task_X_result };
 
 
-        By default $task is required and must be a CodeRef.
-        For example: $task = sub { my $task_X_data = shift; some useful code; return $task_X_result };
+$data can be ArrayRef of your tasks params.
 
-        $data can be ArrayRef of your tasks params. $data = [ $task_data1, $task_data2, ... ];
+    $data = [ $task_data1, $task_data2, ... ];
 
-        Also $data can be HashRef of your tasks params. $data = { task_id1 => $task_data1, task_id2 => $task_data2, ... };
-        In this case you can pass any scalars as keys of this hash. They will be mirrored into result
 
-        The "pool->new()" creates "$pool->tasks_count" count of "$pool->task_class objects".
-        By default task_class is "Async::Simple::Task::Fork".
-        In this case "$pool->tasks_count" processes will be preforked (10 by default).
-        Each of them starts to wait for data which will be provided by pool later.
+Also $data can be HashRef of your tasks params.
+In this case you can pass any scalars as keys of this hash. They will be mirrored into result
 
-        This is the main dispatcher of pool.
-        It behavior depends on %pool_params.
-        If you pass $data to $pool->process, this data will be added to execution.
-        $results = $pool->process( $data );
+$data = { task_id1 => $task_data1, task_id2 => $task_data2, ... };
 
-        Type of $result depends on pool params that you pass in $pool->new( %pool_params );
-        By default result is arrayref.
 
-    Yet another step, %pool_params:
+The "pool->new()" creates "$pool->tasks_count" count of "$pool->task_class objects".
+By default task_class is "Async::Simple::Task::Fork".
+In this case "$pool->tasks_count" processes will be preforked (10 by default).
+Each of them starts to wait for data which will be provided by pool later.
+
+
+This is the main dispatcher of pool. It behavior depends on %pool_params.
+If you pass $data to $pool->process, this data will be added to execution.
+
+    $results = $pool->process( $data );
+
+
+Type of $result depends on pool params that you pass in $pool->new( %pool_params );
+By default result is arrayref.
+
+
+You can use these %pool_params:
 
         data          - ArrayRef/HashRef. A data for tasks, as described above,
 
@@ -91,51 +98,51 @@ Async::Simple::Pool - Simple manager of asyncronous tasks
         task_params   - Any params you wish to pass to each task object to $task->new( %$here ).
 
 
-    Last step: your own task class:
+The last way to use pool is to make your own task class.
+You can make your own class of task. This class MUST has at least this code:
 
-        You can make your own class of task. This class MUST has at least this code:
+    package Your::Task::Class;
 
-        package Your::Task::Class;
+    use parent 'Async::Simple::Task';
 
-        use parent 'Async::Simple::Task';
+    # Trying to read result.
+    # If result found, call $self->result( $result );
+    # If result is not ready, do nothing
+    sub get {
+        my $self = shift;
 
-        # Trying to read result.
-        # If result found, call $self->result( $result );
-        # If result is not ready, do nothing
-        sub get {
-            my $self = shift;
+        return unless you have result;
 
-            return unless you have result;
+        # result can be undef; Don't worry, all will be ok!
+        $self->result( $result );
+    };
 
-            # result can be undef; Don't worry, all will be ok!
-            $self->result( $result );
-        };
+    # Just push data to execution in your way
+    sub put {
+        my ( $self, $data ) = @_;
 
-        # Just push data to execution in your way
-        sub put {
-            my ( $self, $data ) = @_;
+        $self->clear_answer; # Optional, if you plan to use your package regardlessly from this pool.
 
-            $self->clear_answer; # Optional, if you plan to use your package regardlessly from this pool.
+        # Pass your data to your processor here
+    }
 
-            # Pass your data to your processor here
-        }
+    1;
 
-        1;
 
 =head1 DESCRIPTION
 
-    Allows to work with pool of async processes.
+Allows to work with pool of async processes.
 
-    There are many other similar packages you can find on CPAN: Async::Queue, Anyevent::FIFO, Task::Queue, Proc::Simple.
+There are many other similar packages you can find on CPAN: Async::Queue, Anyevent::FIFO, Task::Queue, Proc::Simple.
 
-    The main difference of this package is convenience and simplicity of usage.
+The main difference of this package is convenience and simplicity of usage.
 
 
 =head1 METHODS
 
-    $pool->new
+    $pool->new( various params as described above )
 
-    $pool->process
+    $pool->process( $optional_data_ref )
 
 
 =head1 SUPPORT AND DOCUMENTATION
@@ -188,19 +195,22 @@ use namespace::autoclean;
 use Class::Load;
 use Clone;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head2 data
 
-    You can pass hashref or arrayref as data
+You can pass hashref or arrayref as data
 
-    When it is array, then each item of it will be passed to task as task params
-    ids for internal format will be generated automatically by increasing from 0
+When it is array, then each item of it will be passed to task as task params
+ids for internal format will be generated automatically by increasing from 0
 
-    When is is hashref, then each value of hash will be passed to task as task params
-    ids for internal format will be the same as in your hash
+When is is hashref, then each value of hash will be passed to task as task params
+ids for internal format will be the same as in your hash
+
+In both cases it converts to internal format:
+
+    { id => { source => paramref1, result => if_processed1 }, { source => paramref2, result => if_processed2 },  ... };
 
-    In both cases it converts to internal format = { id => { source => paramref1, result => if_processed1 }, { source => paramref2, result => if_processed2 },  ... };
 =cut
 
 has data => (
@@ -212,7 +222,7 @@ has data => (
 
 =head2 tasks_count
 
-    Tasks_count - a number of tasks that will be created (defailt is 10).
+tasks_count - an integer number of tasks that will be created (defailt is 10).
 
 =cut
 
@@ -226,7 +236,7 @@ has tasks_count => (
 
 =head2 flush_data
 
-    flush_data - remove used data and results after is has been readed in $self->process;
+flush_data - (1|0) - remove used data and results after is has been readed in $self->process;
 
 =cut
 
@@ -239,7 +249,7 @@ has flush_data => (
 
 =head2 result_type
 
-    results_type = [hash|list|fulllist]
+defines structure of results. results_type = (hash|list|fulllist)
 
     when 'list'     - returns all results as list without placing them to the order of source data
 
@@ -258,7 +268,7 @@ has result_type => (
 
 =head2 break_on
 
-    Condition of stopping waiting for results and do something other before next check.
+Condition of stopping waiting for results and do something other before next check.
 
     'busy' = $self->process will exit after filling all the tasks with tasks, without any checks
 
@@ -279,9 +289,7 @@ has break_on => (
 
 =head2 task_class
 
-    Task object class name
-
-    Default is 'Async::Simple::Fork'
+Task object class name. Default is 'Async::Simple::Fork'.
 
 =cut
 
@@ -295,11 +303,12 @@ has task_class => (
 
 =head2 task_params
 
-    Task init params.
+Task init params.
 
-    You can pass all these params directly into pool constructor.
+Pool will push all these params to task->new( here ).
 
-    In this case task_params will be separated by magic;)
+You can pass all these params directly into pool constructor.
+In this case task_params will be separated by magic;)
 
 =cut
 
@@ -340,6 +349,8 @@ has all_keys => (
 
 =head2 new( some various params )
 
+some ways to call it:
+
     my $pool    = Async::Simple::Pool->new( $task );                   # Process should be started below.
 
     my $pool    = Async::Simple::Pool->new( $task, \@data );           # Process will be started inside new.
@@ -351,7 +362,7 @@ has all_keys => (
     my $pool = Async::Simple::Pool->new( task => $task );              # Minimal init with hash of params, all by default, process sould be started manually below
 
 
-    # full list of params for default task type (Async::Simple::Fork) with default values.
+full list of params for default task type (Async::Simple::Fork) with default values.
 
     my $pp = Async::Simple::Pool->new(
         tasks_count   => 10,
@@ -364,8 +375,7 @@ has all_keys => (
         },
     );
 
-    It is a good idea to run new() before gathering all this huge amount of data,
-    and run $pool->process separately:
+It is a good idea to run new() before gathering all this huge amount of data, and run $pool->process separately:
 
     my $pool = Async::Simple::Pool->new( $task );
 
@@ -417,8 +427,7 @@ around BUILDARGS => sub {
 
 =head2 BUILD
 
-    Internal.
-    overrided init for magic with params.
+Internal. Overrided init for magic with params.
 
 =cut
 
@@ -443,18 +452,18 @@ sub BUILD {
 
 =head2 process
 
-    Main dispatcher of child tasks
+Main dispatcher of child tasks
 
     - writes data to tasks
 
-    - checks for reasults
+    - checks for results
 
 
-    We don't care about all internal fails, dying or hang ons of your tasks.
+We don't care about all internal fails, dying or hang ons of your tasks.
 
-    If your task can do something bad, please write workaround for this case inside your "sub".
+If your task can do something bad, please write workaround for this case inside your "sub".
 
-    Will be called inside new() in case you pass data there.
+Will be called inside new() in case you pass data there.
 
 =cut
 
@@ -495,10 +504,10 @@ sub process {
 
 =head2 results
 
-    Internal.
-    Returns all results that already gathered
-    by default returns hash, where keys equal to indexes of source data list
-    and values are the results for data at these indexes
+Internal.
+Returns all results that already gathered
+by default returns hash, where keys equal to indexes of source data list
+and values are the results for data at these indexes.
 
 =cut
 
@@ -535,9 +544,9 @@ sub results {
 
 =head2 make_tasks
 
-    Internal.
-    All tasks are created here.
-    Called from constructor.
+Internal.
+All tasks are created here.
+Called from constructor.
 
 =cut
 
@@ -557,8 +566,8 @@ sub make_tasks {
 
 =head2 read_tasks
 
-    Internal.
-    Reads busy tasks.
+Internal.
+Reads busy tasks.
 
 =cut
 
@@ -583,8 +592,8 @@ sub read_tasks {
 
 =head2 write_tasks
 
-    Internal.
-    Writes to free tasks.
+Internal.
+Writes to free tasks.
 
 =cut
 
@@ -613,8 +622,8 @@ sub write_tasks {
 
 =head2 _conv_data_to_internal
 
-    Internal.
-    Converts source data ( hashref or arrayref ) to internal representation ( hashref ).
+Internal.
+Converts source data ( hashref or arrayref ) to internal representation ( hashref ).
 
 =cut
 
