@@ -6,6 +6,7 @@ package Async::Simple::Task::Fork;
     It waits for "data" whic will be passed via "put", and executed "sub" with this "data" as an argument.
     Result of execution will be returned to parent by "get".
 
+
 =head1 SYNOPSIS
 
     use Async::Simple::Task::Fork;
@@ -26,9 +27,9 @@ package Async::Simple::Task::Fork;
 
     $task->put( $data );                                           # Put another data to task sub and so on,....
 
-    Result and data can be of any type and deep which can be translated via Data::Serializer->new( serializer => Storable ) # by default
+Result and data can be of any type and deep which can be translated via Data::Serializer->new( serializer => Storable ) # by default
 
-    If your "sub" can return undef you should check $task->has_result, as a mark that result is ready.
+If your "sub" can return undef you should check $task->has_result, as a mark that result is ready.
 
 
 =head1 DESCRIPTION
@@ -42,33 +43,33 @@ After that, executes "sub" for each "data" passed to child process.
 
 =head2 C<new>
 
-    Forks a process
+Forks a process
 
     my $task = Async::Simple::Task::Fork->new( task => &$sub, %other_optional_params );
 
-    Params: # all param except "task" are optional
+Params (all param except "task" are optional):
 
-        task         => coderef, function, called for each "data" passed to child process via $task->put( $data );
+    task         => coderef, function, called for each "data" passed to child process via $task->put( $data );
 
-        timeout      => timeout in seconds between child checkings for new data passed. default 0.01
+    timeout      => timeout in seconds between child checkings for new data passed. default 0.01
 
-        kill_on_exit => kill (1) or not (0) subprocess on object destroy (1 by default).
+    kill_on_exit => kill (1) or not (0) subprocess on object destroy (1 by default).
 
 
 =head2 C<put>
 
-    Puts data to task.
+Puts data to task.
 
     $self->put( $data );
 
 
 =head2 C<get>
 
-    Tries to read result from task.
+Tries to read result from task.
 
-    Returns undef if it is not ready.
+Returns undef if it is not ready.
 
-    In case, your function can return undef, you shoud check $task->has_answer, as a mark of ready result.
+In case, your function can return undef, you shoud check $task->has_answer, as a mark of ready result.
 
     my $result = $self->get();
 
@@ -96,7 +97,7 @@ After that, executes "sub" for each "data" passed to child process.
 
 =head1 AUTHOR
 
-    ANTONC <antonc@cpan.org>
+ANTONC <antonc@cpan.org>
 
 =head1 LICENSE
 
@@ -116,7 +117,7 @@ use namespace::autoclean;
 use Data::Serializer;
 use Time::HiRes qw/ alarm sleep /;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 extends 'Async::Simple::Task';
@@ -143,30 +144,30 @@ has task => (
 
 =head2 answer
 
-    Result of current task
+Result of current task
 
 =cut
 
 
 =head2 has_answer
 
-    true, if the task has been finished and result has been ready
+has_answer is true, if the task has been finished and result has been ready
 
 =cut
 
 
 =head2 timeout
 
-    timeout - positive numeric value = seconds between checking for result
+timeout - positive numeric value = seconds between checking for result.
 
-    inherited from Async::Simple::Task
+inherited from Async::Simple::Task.
 
 =cut
 
 
 =head2 kill_on_exit
 
-    Kills process from parent in case of object desctuction
+Kills process from parent in case of object desctuction
 
 =cut
 
@@ -220,24 +221,26 @@ has pid => (
     my $task = Async::Simple::Task::Fork->new( %all_optional_params );
 
 
-    Possible keys for %all_optional_params:
+Possible keys for %all_optional_params:
 
-        task         => coderef, function, called for each "data" passed to child process via $task->put( $data );
+    task         => coderef, function, called for each "data" passed to child process via $task->put( $data );
 
-        timeout      => timeout in seconds between child checkings for new data passed. default 0.01
+    timeout      => timeout in seconds between child checkings for new data passed. default 0.01
 
-        kill_on_exit => kill (1) or not (0) subprocess on object destroy (1 by default).
+    kill_on_exit => kill (1) or not (0) subprocess on object destroy (1 by default).
 
 =cut
 
 
 =head2 BUILD
-    internal
-    some tricks here:)
+
+internal. Some tricks here:)
+
     1. Master process called $task->new with fork() inside
     2. After forking done we have two processes:
     2.1. Master gets one side of reader/writer pipes and pid of child
     2.2. Child - another side of pipes and extra logic with everlasting loop
+
 =cut
 
 sub BUILD {
@@ -268,7 +271,7 @@ sub BUILD {
 
 =head2 fork_child
 
-    Makes child process and returns pid of child process to parent or 0 to child process
+Makes child process and returns pid of child process to parent or 0 to child process
 
 =cut
 
@@ -313,11 +316,12 @@ sub fork_child {
 
 =head2 get
 
+Reads from task, if something can be readed or returns undef after timeout.
+
     my $result = $task->get;
 
-    Reads from task, if something can be readed or returns undef after timeout.
+Please note! If your function can return an undef value, then you shoud check
 
-    Please note! If your function can return an undef value, then you shoud check
     $task->has_result.
 
 =cut
@@ -358,9 +362,10 @@ sub get {
 
 =head2 put
 
+Writes task to task.
+
     $task->put( $data );
 
-    Writes task to task.
 
 =cut
 
@@ -380,10 +385,11 @@ sub put {
 
 =head2 get_serializer
 
-    Return an object that must have 2 methods: serialize and deserialize.
-    By default returns Data::Serializer with Storable as backend.
+Internal. Returns an object that must have 2 methods: serialize and deserialize.
+By default returns Data::Serializer with Storable as backend.
 
     $self->serializer->serialize( $task_data_ref );
+
     $result_ref = $self->serializer->deserialize();
 
 =cut
@@ -397,7 +403,7 @@ sub get_serializer {
 
 =head2 DEMOLISH
 
-    Destroys object and probably should finish the child process.
+Destroys object and probably should finish the child process.
 
 =cut
 
